@@ -119,7 +119,7 @@ class HelpersTest < Devise::ControllerTestCase
     MyController.send(:public, :navigational_formats)
 
     swap Devise, navigational_formats: ['*/*', :html] do
-      assert_not @controller.navigational_formats.include?("*/*")
+      refute @controller.navigational_formats.include?("*/*")
     end
 
     MyController.send(:protected, :navigational_formats)
